@@ -35,6 +35,8 @@ from CustomIntents.Bcolor import bcolors
 
 import pkg_resources
 
+import gradio as gr
+
 
 class VideoStream:
 
@@ -98,7 +100,7 @@ class BinaryImageClassificator:
                     if tip not in image_exts:
                         print('Image not in ext list {}'.format(image_path))
                         os.remove(image_path)
-                except Exception as e:
+                except Exception:
                     print('Issue with image {}'.format(image_path))
                     os.remove(image_path)
 
@@ -108,7 +110,7 @@ class BinaryImageClassificator:
         self.batch = self.data_iterator.next()
         print(f"{bcolors.OKGREEN}loading data succsesfuly{bcolors.ENDC}")
 
-    def scale_data(self, model_type="s1"):
+    def scale_data(self):
         self.data = self.data.map(lambda x, y: (x / 255, y))
         print(f"{bcolors.OKGREEN}scaling data succsesfuly{bcolors.ENDC}")
 
@@ -126,7 +128,7 @@ class BinaryImageClassificator:
 
     def split_data(self, validation_split=0.2):
         self.train_size = int(len(self.data) * (1 - validation_split))
-        self.val_size = int(len(self.data) * (validation_split))
+        self.val_size = int(len(self.data) * validation_split)
         self.test_size = int(len(self.data) * .0)
         self.train = self.data.take(self.train_size)
         self.val = self.data.skip(self.train_size).take(self.val_size)
@@ -280,7 +282,7 @@ class BinaryImageClassificator:
         self.oom_avoider()
         self.remove_dogy_images()
         self.load_data()
-        self.scale_data(model_type=model_type)
+        self.scale_data()
         self.augmanet_data(model_type=model_type)
         self.split_data(validation_split=validation_split)
         if prefetching:
@@ -334,17 +336,34 @@ class BinaryImageClassificator:
         resize = tf.image.resize(img, (256, 256))
         yhat = self.model.predict(np.expand_dims(resize / 255, 0))
         if yhat > 0.5:
-            return self.first_class, ((yhat * 2) - 0.5) * 100
+            return self.first_class, ((yhat[0][0] - 0.5) * 2) * 100
         else:
-            return self.second_class, (1 - (yhat * 2)) * 100
+            return self.second_class, (1 - (yhat[0][0] * 2)) * 100
 
     def predict_from_imshow(self, img):
         resize = tf.image.resize(img, (256, 256))
         yhat = self.model.predict(np.expand_dims(resize / 255, 0))
         if yhat > 0.5:
-            return self.first_class
+            return self.first_class, ((yhat[0][0] - 0.5) * 2) * 100
         else:
-            return self.second_class
+            return self.second_class, (1 - (yhat[0][0] * 2)) * 100
+
+    def predict_from_numpy(self, img):
+        resize = tf.image.resize(img, (256, 256))
+        yhat = self.model.predict(np.expand_dims(resize / 255, 0))
+        if yhat > 0.5:
+            return self.first_class, ((yhat[0][0] - 0.5) * 2) * 100
+        else:
+            return self.second_class, (1 - (yhat[0][0] * 2)) * 100
+
+    def gradio_preview(self, share=False, inbrowser=True):
+        demo = gr.Interface(self.predict_from_numpy,
+                            inputs=gr.Image(label="your image"),
+                            outputs=[gr.Label(label="class"),
+                                     gr.Label(label="Accuracy")],
+                            allow_flagging="never")
+        print(f"open http://localhost:7860 for viewing your model preview")
+        demo.launch(share=share, inbrowser=inbrowser)
 
     def evaluate_model(self):
         self.pre = Precision()
